---
title: "About"
date: 2023-07-10
draft: false
---

# About the Community Dispute Protocol Builder

The Dispute Protocol Builder is a collaborative tool designed to help communities develop customized frameworks for addressing and resolving conflicts. Rather than imposing a one-size-fits-all solution, this tool empowers communities to create protocols that reflect their unique values, culture, and specific needs.

## Why Create a Dispute Protocol?

Every community experiences conflicts. Whether in neighborhoods, workplaces, cooperatives, online spaces, or cultural groups, disagreements and tensions are inevitable. Having a thoughtful, agreed-upon process for addressing these conflicts provides numerous benefits:

- **Prevents escalation** of small issues into major conflicts
- **Creates consistency** and predictability during challenging times
- **Ensures fairness and transparency** in how issues are addressed
- **Reduces harm** during the resolution process
- **Builds community capacity** to handle future conflicts
- **Strengthens relationships** by demonstrating commitment to healthy conflict engagement
- **Embodies community values** in practical, actionable ways
- **Provides guidance** when emotions are running high

Without a clear protocol, communities often default to ad-hoc approaches that can amplify harm, reinforce power imbalances, or leave conflicts unresolved.

## How the Builder Works

The Protocol Builder guides you through creating a comprehensive dispute resolution framework using a modular approach:

### 1. Start from Templates or Build from Scratch

Begin with one of our pre-designed templates based on restorative justice, transformative justice, or consensus-based approaches—or start with a blank slate and build your own custom protocol.

### 2. Customize Each Stage

The builder walks you through six key stages of dispute resolution:

1. **Preparation**: Establishing core values, principles, and participant roles
2. **Initiation**: Defining how disputes are raised, acknowledged, and entered into the process
3. **Exploration**: Investigating and understanding the facts, perspectives, and underlying needs
4. **Deliberation**: Discussing potential solutions and working toward agreements
5. **Resolution**: Finalizing, documenting, and implementing solutions
6. **Follow-up**: Evaluating outcomes, ensuring accountability, and making improvements

### 3. Mix and Match Modules

For each component within these stages, you can select from pre-written modules or craft your own content. This modular approach lets you:

- Choose elements that align with your community's values
- Adapt the protocol based on your community's capacity and resources
- Create a coherent process that addresses your specific needs
- Ensure nothing important is overlooked

### 4. Export and Share

When your protocol is complete, export it as:
- A formatted PDF to share with your community
- A Markdown document for easy editing and version control
- A JSON file that can be imported back into the builder for future updates

## Design Principles

The Dispute Protocol Builder is designed around these core principles:

- **Accessibility**: Simple, clear language and an intuitive interface make this tool usable by anyone, regardless of technical expertise or familiarity with conflict resolution terminology.

- **Flexibility**: Every component is customizable to accommodate diverse community contexts and needs.

- **Comprehensiveness**: The tool addresses all aspects of dispute resolution, from initial values to final implementation.

- **Educational**: Pre-written modules offer best practices drawn from various dispute resolution traditions.

- **Privacy-Focused**: All work happens locally in your browser—no data is sent to our servers.

## Who Is This For?

This tool is designed for any group that wants to improve how they handle internal conflicts:

- **Intentional Communities and Cooperatives**
- **Neighborhood Associations**
- **Activist Groups and Collectives**
- **Small Businesses and Worker Cooperatives**
- **Faith Communities**
- **Online Communities and Forums**
- **Educational Institutions**
- **Non-Profit Organizations**
- **Artistic and Cultural Collectives**

## Get Started

<div class="cta-container">
Ready to create your community's dispute protocol? 

<a href="/builder" class="cta-button">Start Building Your Protocol</a>
</div>