// Chosen Facilitator Template

const chosenFacilitatorTemplate = {
  id: "chosen-facilitator",
  title: "Chosen Facilitator",
  description: "A process where participants mutually select a facilitator to help guide their dispute resolution",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Community rules and the dispute resolution protocol are available on the community website and in a physical binder kept in the community center. New members receive an orientation to these guidelines when they join."
        },
        shared_values: {
          sharedValuesText: "Our community values open dialogue, mutual respect, and collaborative problem-solving. We believe that most conflicts can be resolved through good faith communication with appropriate support. We prioritize repairing relationships and finding solutions that address underlying needs rather than simply ending disputes."
        },
        information_access: {
          informationAccessText: "Information is shared on a need-to-know basis. The Community Relations Committee keeps records of disputes, and the parties involved have access to all documentation related to their case. Annual anonymous statistics about disputes are shared with the community."
        }
      },
      process: {
        process_start: {
          processStartText: "The process begins when a community member submits a dispute form to the Community Relations Committee. The form includes details about the issue, parties involved, and previous attempts at resolution. The committee acknowledges receipt within 24 hours. Within 48 hours of receiving a dispute form, the committee contacts all named parties and provides them with a copy of the form and information about the process."
        },
        facilitation: {
          facilitationText: "The process is guided by a facilitator chosen jointly by all participants from a list of community members who have expressed willingness to serve in this role. The facilitator has basic training in conflict resolution but is not a professional mediator. They help guide the conversation, ensure all voices are heard, and maintain focus on resolution. Meetings take place in a neutral community space, typically a designated meeting room in the community center."
        },
        ground_rules: {
          groundRulesText: "The facilitator establishes ground rules at the beginning of the first session, such as: 1) One person speaks at a time, 2) Focus on issues rather than personal attacks, 3) Use respectful language, 4) Actively listen to understand, 5) Take breaks when needed, and 6) Maintain confidentiality. Participants commit to: engaging honestly and respectfully, selecting a mutually acceptable facilitator, attending all scheduled sessions, respecting confidentiality, working toward resolution in good faith, and abiding by any agreements reached."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "In the first session, the facilitator helps participants create a shared understanding of the situation by: 1) Having each person share their perspective without interruption, 2) Identifying areas of agreement and disagreement, 3) Clarifying facts versus interpretations, and 4) Establishing what resolution would look like. The facilitator helps assess whether the conflict is: a misunderstanding that can be clarified, a disagreement about resources or procedures, a values-based conflict, or a relationship conflict with a history of tension."
        },
        jurisdiction: {
          jurisdictionText: "The facilitator helps determine if the chosen facilitator process is appropriate for the dispute. If the issue involves serious safety concerns, legal violations, or requires specialized expertise, the facilitator will recommend delegation to a more appropriate resource."
        },
        non_participation: {
          nonParticipationText: "Participation is voluntary, though all community members have agreed as part of their membership that they will make a good faith effort to resolve conflicts through the community process before pursuing outside remedies. If someone refuses to participate, the committee may arrange for a mediator to speak with them individually to address concerns and encourage engagement."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "Deliberation typically involves 1-3 sessions of 90-120 minutes each, scheduled about a week apart. This provides time for reflection between sessions. The facilitator sets a clear agenda for each session and manages time to ensure productive discussion. After initial perspectives are shared, the facilitator identifies information gaps and helps participants determine what additional information might be needed."
        },
        additional_voices: {
          additionalVoicesText: "The primary participants and the facilitator attend all sessions. With agreement from all parties, participants may bring one support person to sessions. Support people may speak when invited but primarily provide emotional support and perspective between sessions."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "The facilitator leads a structured brainstorming session where all possible solutions are recorded without criticism. After brainstorming, the facilitator helps participants evaluate options based on previously identified needs and interests. They guide the discussion to focus on finding solutions that address the core concerns of all parties rather than positional bargaining. Deliberation concludes when participants have explored all viable solutions and are ready to make decisions."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Decisions are made by consensus of the participants, with the facilitator helping to test whether proposed solutions are acceptable to everyone. The facilitator may use techniques like fist-to-five voting to gauge levels of support for proposals. Typical outcomes include: mutual understanding and clarified expectations, specific action agreements with timelines, changes to procedures or resources, commitments to specific communication practices, relationship-rebuilding activities, or agreements about future conflict resolution."
        },
        resolution_failure: {
          resolutionFailureText: "If resolution cannot be reached through the facilitated process, the facilitator documents what has been attempted and areas of continuing disagreement. Delegation to a different process is appropriate when: 1) The facilitated process has been attempted without success, 2) The issue requires specialized expertise, 3) There are significant power imbalances that can't be addressed by a peer facilitator, 4) Safety concerns exist, or 5) The dispute has community-wide implications."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "Appeals may be initiated if: 1) New information emerges that could significantly affect the agreement, 2) Circumstances change making the agreement unworkable, 3) There are persistent challenges implementing the agreement, or 4) One or more participants feel the process was unfair."
        },
        appeal_process: {
          appealProcessText: "To appeal, a participant submits a written request to the Community Relations Committee explaining why they believe the agreement needs reconsideration. The committee reviews the request and contacts all original participants to determine next steps. If an appeal proceeds, a new facilitator is selected from the community to provide fresh perspective. This facilitator reviews documentation from the original process and conducts a new series of facilitated sessions focusing on the specific issues raised in the appeal."
        }
      }
    }
  }
};

// Export the template
export default chosenFacilitatorTemplate;