// Facilitation Council Template

const facilitationCouncilTemplate = {
  id: "facilitation-council",
  title: "Facilitation Council",
  description: "A structured process with a trained council of facilitators who manage the dispute resolution process",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Community rules, bylaws, and the detailed dispute resolution protocol are maintained in a searchable online database with version history. Physical copies are available in the community center library. The Facilitation Council conducts quarterly workshops to educate community members about the rules and processes."
        },
        shared_values: {
          sharedValuesText: "Our community dispute resolution process is guided by values of equity, transparency, and restorative justice. We believe in the wisdom of collective decision-making, the importance of diverse perspectives, and the healing potential of structured dialogue. We prioritize relationships while maintaining accountability and upholding community standards."
        },
        information_access: {
          informationAccessText: "Information access follows a tiered model: 1) The involved parties and council members have full access to case documentation, 2) Council administrators track anonymized case data for process improvement, 3) Quarterly reports with statistical information and lessons learned (without identifying details) are shared with the community."
        }
      },
      process: {
        process_start: {
          processStartText: "The dispute resolution process begins when an individual submits a formal request using the council's intake form. This form is available online and in hard copy at the community office. The form requires details about the nature of the dispute, parties involved, and previous resolution attempts. A member of the Facilitation Council acknowledges receipt within 24 hours and assigns an intake coordinator. The intake coordinator contacts all named parties within 48 hours via email and phone."
        },
        facilitation: {
          facilitationText: "Disputes are facilitated by a panel of 2-3 council members who have completed a comprehensive training program in conflict resolution, mediation, and restorative practices. The panel always includes diversity of perspectives and backgrounds. One member serves as the lead facilitator, while others may focus on documentation, process management, or emotional support. The council operates according to established procedures with flexibility to adapt to specific needs of each case."
        },
        ground_rules: {
          groundRulesText: "The council establishes and enforces clear communication protocols: 1) A talking piece indicates who has the floor, 2) Structured speaking order ensures equal voice, 3) Time limits for presentations may be used, 4) Direct communication between parties is facilitated when productive, 5) Council members summarize and reframe statements to ensure understanding, 6) Caucus sessions (private meetings) are available when needed, and 7) Written communication supplements verbal discussion for complex topics. Participants commit to providing complete and truthful information, respecting confidentiality, attending all scheduled meetings, engaging respectfully, and implementing agreed-upon resolutions."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "The council conducts a structured assessment through: 1) Individual interviews with each party, 2) Review of written statements and evidence, 3) Consultation with relevant witnesses, 4) Consideration of applicable community agreements or policies, and 5) Discussion with the full council to identify the nature and scope of the dispute. The council uses a formal assessment framework to determine the history and duration of the conflict, the level of emotion and polarization between parties, whether communication between parties is still functional, and the underlying causes of the dispute."
        },
        jurisdiction: {
          jurisdictionText: "The council follows a jurisdictional assessment checklist to determine if the case is appropriate for their process. Cases involving serious legal violations, safety threats, or requiring specialized expertise beyond the council's capacity are referred to appropriate authorities. For complex cases, the council may establish jurisdiction over certain aspects while referring others. The assessment considers legal requirements, community capacity, and the nature of the dispute."
        },
        non_participation: {
          nonParticipationText: "Participation in the facilitation council process is required for active community members as specified in the community membership agreement. For non-members or in cases where mandatory participation would be inappropriate, the council works with willing participants and documents non-participation of others. If a party refuses to participate, the council may proceed with a modified process, making note of the limitations this creates."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "The council uses a structured information gathering process: 1) Initial statements from all parties, 2) Clarifying questions from council members, 3) Testimony from relevant witnesses, 4) Review of documentary evidence, 5) Expert input if needed for technical matters, and 6) Community standard review when applicable. Information gathering follows a predetermined schedule with deadlines for submissions and specific session agendas."
        },
        additional_voices: {
          additionalVoicesText: "The process includes: 1) Primary parties to the dispute, 2) Council panel members, 3) Witnesses invited by either party or the council (for specific sessions only), 4) Support persons (one per participant, non-speaking unless invited), and 5) In cases affecting community standards, a community representative. For disputes involving allegations of harm, the council uses practices that prevent re-traumatization while ensuring fair process."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "Discussion follows a structured format: 1) Review of brainstormed options, 2) Evaluation against previously identified needs and community values, 3) Consideration of implementation feasibility, 4) Discussion of modifications to promising options, 5) Council-facilitated negotiations on specific details, and 6) Caucus sessions when needed for private discussion. The council maintains focus on interests rather than positions and ensures balanced participation. The council uses a multi-stage deliberation format with most cases involving 3-5 sessions of 2-3 hours each over a 2-4 week period."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "The council uses a tiered decision-making approach: 1) Facilitated consensus among parties is the preferred method, with the council helping parties reach mutually acceptable agreements, 2) If consensus cannot be reached on all issues after good faith efforts, parties may authorize the council to make recommendations on specific points, 3) In cases involving community standards or policies, the council may make binding decisions following established criteria. Resolution outcomes may include written agreements between parties with specific commitments, action plans with timelines, restorative agreements to address harm, resource allocation decisions, and clarification of policies or expectations."
        },
        resolution_failure: {
          resolutionFailureText: "If resolution is not achieved through the council process, several options are considered: 1) Referral to a specialized mediator or arbitrator with expertise in the specific dispute area, 2) Escalation to the community's governance body for policy-level resolution, 3) In cases involving legal dimensions, referral to appropriate legal resources, 4) Recommendation for separate processes to address different aspects of complex disputes, or 5) Implementation of interim measures to stabilize the situation while longer-term solutions are developed."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "Appeals may be filed when: 1) New, significant evidence emerges that was not available during the original process, 2) There was a substantial procedural error that may have affected the outcome, 3) The agreement has proven unworkable despite good faith implementation efforts, or 4) There has been a significant change in circumstances that renders the agreement ineffective. Appeals must be filed within 30 days of discovering the grounds for appeal."
        },
        appeal_process: {
          appealProcessText: "The appeal process includes: 1) Submission of a formal appeal request specifying grounds for appeal and desired outcome, 2) Review by council members not involved in the original case to determine if appeal criteria are met, 3) Notification to all original parties, 4) If accepted, assignment of a new council panel, 5) Structured review of original documentation and new evidence, 6) Limited-scope hearings focused on appeal issues, 7) Decision rendered within 30 days of appeal acceptance."
        }
      }
    }
  }
};

// Export the template
export default facilitationCouncilTemplate;