// Community Jury Protocol Template

const juryProtocolTemplate = {
  id: "jury-protocol",
  title: "Community Jury",
  description: "A process where a randomly selected jury of community members hears evidence and makes decisions on disputes",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Community standards and jury procedures are publicly available through multiple channels: 1) A comprehensive online handbook with searchable content, 2) Print copies in the community center, 3) Audio recordings for accessibility, and 4) Regular community education sessions. New residents receive an orientation to these standards during their welcome process. The Jury Administrator is available to answer questions about procedures."
        },
        shared_values: {
          sharedValuesText: "Our community jury system is grounded in these core values: 1) Procedural fairness - ensuring consistent, transparent processes, 2) Collective wisdom - trusting in the reasoned judgment of peers, 3) Community ownership - placing decision-making authority within the community, 4) Balanced perspective - bringing diverse viewpoints to each case, 5) Reasoned judgment - basing decisions on evidence and community standards, and 6) Restorative outcomes - seeking decisions that repair harm and rebuild relationships."
        },
        information_access: {
          informationAccessText: "Information about specific cases follows tiered access protocols: 1) Case parties receive all documentation relevant to their case, 2) Jury members receive case materials with sensitive personal information redacted, 3) The wider community receives notification of cases accepted and decisions made without identifying details, 4) Case summaries with key learnings are published annually for community education. Records are maintained securely by the Jury Administrator."
        }
      },
      process: {
        process_start: {
          processStartText: "The community jury process begins when a community member submits a case request form. This form includes details about the issue, parties involved, attempts at resolution so far, and desired outcome. The Jury Administrator reviews all submissions within 3 business days to determine if the case meets basic criteria for the jury process. If accepted, the case is assigned a number and scheduled for an initial hearing date."
        },
        facilitation: {
          facilitationText: "The dispute process is facilitated through a structured jury format: 1) A trained process facilitator guides the proceedings but does not participate in decision-making, 2) The process follows clear phases: opening statements, evidence presentation, questions, deliberation, and decision, 3) All parties have equal time to present their perspectives and evidence, 4) Jurors may ask clarifying questions through the facilitator, 5) The facilitator ensures adherence to community standards and procedural fairness, 6) Deliberations are conducted by jurors alone, with the facilitator available for procedural questions."
        },
        ground_rules: {
          groundRulesText: "Communication during jury proceedings follows formal protocols: 1) Opening and closing statements are uninterrupted and time-limited, 2) Evidence presentation follows a structured format with visual aids as needed, 3) Questions from jurors are submitted to the facilitator, who may rephrase for clarity, 4) Cross-examination is limited and focused on fact clarification rather than confrontation, 5) The facilitator moderates all exchanges to maintain respectful discourse, 6) Emotional expression is allowed but must remain appropriate to the setting. All participants in the jury process commit to: providing truthful information and evidence, adhering to scheduled deadlines and hearing dates, treating all participants with respect, and accepting the jury's decision as binding within community governance."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "The jury assesses each case through a structured framework: 1) Establishing agreed-upon facts versus disputed elements, 2) Identifying relevant community standards or agreements that apply, 3) Evaluating the credibility and completeness of evidence presented, 4) Considering context and mitigating circumstances, 5) Assessing impacts on individuals and the community, and 6) Determining responsibility based on the preponderance of evidence. The jury considers the stage and history of the conflict, including whether this is a first-time issue or recurring pattern, previous attempts at resolution, and the current relationship between the parties."
        },
        jurisdiction: {
          jurisdictionText: "The community jury has jurisdiction over: 1) Disputes between community members regarding shared resources or spaces, 2) Alleged violations of community agreements or standards, 3) Conflicts affecting community function or wellbeing, 4) Requests for clarification of policies or practices, and 5) Appeals of decisions made by community committees. The jury does not have jurisdiction over legal matters requiring formal court proceedings, situations presenting immediate safety risks, or disputes that have been explicitly excluded in the community charter."
        },
        non_participation: {
          nonParticipationText: "For community members, participation in the jury process is required as specified in the community agreement signed upon joining. For non-members or external entities, participation is voluntary. If a respondent declines to participate, the jury may still hear the case and reach a decision based on available information, but will note the limited nature of the proceedings. When a case is accepted, all named parties receive formal notification through both email and paper letter with a response form to be returned within 10 days."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "Jury information gathering continues during deliberation: 1) Jurors identify information gaps that emerged during the hearing, 2) They may request clarification from parties through written questions, 3) They review all submitted evidence methodically, creating an evidence summary, 4) They consult community standards and precedents from previous similar cases, 5) If needed, they may request additional expert input on technical matters, and 6) They document key findings of fact that will form the basis for their decision."
        },
        additional_voices: {
          additionalVoicesText: "Jury proceedings involve the following participants: 1) The 5-7 community members selected as jurors through a structured random process, 2) The case parties (initiator and respondent), 3) A trained facilitator who guides the process, 4) Witnesses called by either party or the jury itself, 5) The Jury Administrator who manages logistics and record-keeping, and 6) Community observers who may attend open portions of the hearings. Expert testimony may be sought when specialized knowledge is required."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "Jury deliberation discussions follow a structured format: 1) The jury first clarifies the key questions that must be answered, 2) They review evidence related to each question, 3) Each juror shares their perspective on how the evidence answers these questions, 4) Areas of agreement and disagreement are explicitly identified, 5) For disagreements, jurors explore underlying reasoning and concerns, 6) The facilitator helps maintain focus and ensures all voices are heard, and 7) The jury works toward finding areas of consensus before moving to formal decision-making."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Decisions are made through a structured jury voting process: 1) After thorough deliberation, the jury votes on proposed resolutions, 2) A 2/3 majority is required for decisions to be adopted, 3) If the first vote doesn't reach the threshold, further discussion occurs, 4) Up to three voting rounds may take place to reach the required majority, 5) If consensus cannot be reached after three rounds, the most supported option with at least 60% support is adopted, 6) The jury provides written rationale for their decision based on community standards, 7) Jury decisions are binding within the scope of community governance."
        },
        resolution_failure: {
          resolutionFailureText: "If the jury process fails to resolve the dispute effectively, several options are available: 1) Referral to professional mediation or arbitration, 2) Escalation to formal legal proceedings when appropriate, 3) Revision of community policies or procedures if the case reveals structural issues, 4) Implementation of additional support mechanisms for the affected parties, or 5) In rare cases where resolution seems impossible, the community may recommend separation of the parties through reassignment of roles or spaces."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "Appeals of jury decisions may be filed based on specific criteria: 1) Significant new evidence that wasn't available during the original hearing, 2) Procedural errors that materially affected the outcome, 3) Clear misapplication of community standards by the jury, 4) Jury bias or misconduct that affected the decision, or 5) Implementation difficulties that make the decision unworkable. Appeals must be filed within 14 days of the decision and must specifically identify which criteria apply."
        },
        appeal_process: {
          appealProcessText: "The appeal process follows these steps: 1) The appellant submits a written appeal stating the grounds and desired outcome, 2) The Appeal Committee (three community members not involved in the original case) reviews the appeal to determine if it meets criteria, 3) If accepted, a new jury is selected, larger than the original, 4) The new jury reviews all original materials plus the appeal documentation, 5) A limited appeal hearing is held focusing only on the specific grounds for appeal, 6) The appeal jury deliberates and issues a new decision that either confirms, modifies, or overturns the original decision."
        }
      }
    }
  }
};

// Export the template
export default juryProtocolTemplate;