// Peer-to-Peer Protocol Template

const peerToPeerTemplate = {
  id: "peer-to-peer",
  title: "Peer-to-Peer",
  description: "A self-facilitated process where participants work together directly to resolve disputes",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Community rules are kept in a shared digital repository accessible to all members, with physical copies posted in community spaces. Rules are reviewed annually in a community-wide meeting."
        },
        shared_values: {
          sharedValuesText: "Our community values open communication, mutual respect, and collaborative problem-solving. We believe in addressing conflicts directly and focusing on solutions rather than blame. We prioritize maintaining relationships while addressing legitimate concerns."
        },
        information_access: {
          informationAccessText: "Information about disputes is shared only with those directly involved in the process. A summary of resolved disputes (with identifying details removed) is shared quarterly to help the community learn and improve processes."
        }
      },
      process: {
        process_start: {
          processStartText: "The dispute process begins when a community member fills out an incident report form. This form includes details about the parties involved in the dispute, a description of what happened, including dates and times, any relevant evidence or documentation, and a description of the outcome the person is seeking. The form can be submitted electronically through our community portal or as a paper form to the designated community coordinator."
        },
        facilitation: {
          facilitationText: "This process is self-facilitated by the participants. Both parties review a shared guidance document on productive communication before meeting. This document includes suggested time frames, communication techniques, and a basic structure for the conversation. Participants choose a neutral location that feels comfortable for both parties. This could be a community meeting room, quiet outdoor space, or online video call if necessary."
        },
        ground_rules: {
          groundRulesText: "Participants follow these guidelines: 1) Take turns speaking without interruption, 2) Use 'I' statements to express feelings and needs, 3) Ask clarifying questions, 4) Summarize what you've heard to ensure understanding, 5) Focus on the present issue and future solutions rather than past grievances. Participants commit to: communicating honestly and respectfully, listening to understand rather than to respond, working toward a mutually beneficial resolution, respecting confidentiality, and following through on any agreed-upon actions."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "Participants assess the situation together by identifying: 1) The specific issue or behavior causing concern, 2) The impact on each person and the community, 3) Related community values or agreements, and 4) What needs to happen for resolution. Each participant identifies and shares their underlying needs, such as respect, clarity, security, fairness, autonomy, or community connection."
        },
        jurisdiction: {
          jurisdictionText: "The peer-to-peer process is appropriate for most interpersonal conflicts and minor disagreements. If the dispute involves illegal activity, poses safety risks, or requires specialized expertise, participants should refer to the delegation process."
        },
        non_participation: {
          nonParticipationText: "Participation is voluntary but strongly encouraged. Community members have agreed in advance that the peer resolution process is the first step before escalating disputes to other forums. If someone refuses to participate, the community coordinator will reach out to understand their concerns and encourage engagement."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "The deliberation is a face-to-face conversation (or video call if necessary) that typically lasts 60-90 minutes. Participants ask each other clarifying questions to ensure they fully understand the situation. They may take a break to gather more information if needed before continuing the conversation. Participants jointly brainstorm potential solutions without immediately evaluating them."
        },
        additional_voices: {
          additionalVoicesText: "Only the directly involved parties participate in the initial conversation. If they reach an impasse, they may jointly decide to invite a mutual trusted friend to help facilitate a follow-up conversation. This third person does not make decisions but helps maintain productive communication."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "Discussion follows the format of: 1) Each person shares their perspective uninterrupted, 2) Clarifying questions are asked, 3) Areas of agreement and difference are identified, 4) Participants work to find solutions that address core needs of all involved. Deliberation concludes when participants feel they have explored all relevant aspects of the issue and are ready to make decisions."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Decisions are made through mutual agreement. Both participants must consent to the resolution, meaning they can live with the decision even if it isn't their ideal outcome. Possible outcomes include: clarification of misunderstandings, apologies and acknowledgment of impact, agreements about future behavior, specific actions to restore harm, plans for ongoing communication, or agreement to disagree respectfully on certain matters."
        },
        resolution_failure: {
          resolutionFailureText: "If participants cannot reach a resolution through the peer-to-peer process, they document what has been tried and what issues remain unresolved. They then request assistance from the community mediator pool, a group of trained volunteer mediators who can facilitate a more structured process. These mediators also maintain referral relationships with professional mediators, counselors, and legal services as needed."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "If either participant feels the agreement isn't working or circumstances have changed significantly, they can request a follow-up conversation using the same peer-to-peer process."
        },
        appeal_process: {
          appealProcessText: "To revisit the agreement, the participant sends a written request to the other party explaining why they believe the agreement needs adjustment. They then schedule a new conversation following the same format as the original process. The follow-up conversation focuses specifically on the aspects of the agreement that aren't working, rather than reopening the entire dispute."
        }
      }
    }
  }
};

// Export the template
export default peerToPeerTemplate;