// Community Referee Protocol Template

const refereeProtocolTemplate = {
  id: "referee-protocol",
  title: "Community Referee",
  description: "A streamlined process where a single trained referee facilitates and decides on dispute resolution",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Community standards and the referee process guidelines are made accessible through: 1) A comprehensive digital handbook available on the community website, 2) Print copies in the community office, 3) Periodic community workshops explaining the process, and 4) A quick-reference guide that summarizes key points. New community members receive orientation to these materials when they join. The Dispute Coordinator is available to answer questions about the process."
        },
        shared_values: {
          sharedValuesText: "The referee process embodies these essential values: 1) Efficiency - streamlining resolution to minimize time and resources, 2) Fairness - ensuring balanced consideration and equal opportunity to be heard, 3) Expertise - bringing relevant knowledge and skills to complex situations, 4) Practicality - focusing on workable solutions that can be implemented, 5) Consistency - applying community standards evenly across similar cases, and 6) Respect - maintaining dignity for all participants throughout the process."
        },
        information_access: {
          informationAccessText: "Information management follows clear confidentiality protocols: 1) Case information is shared only with the assigned referee and parties directly involved, 2) Documentation is stored securely in both digital and physical formats, 3) Anonymized statistical information is compiled quarterly for process improvements, 4) Final determinations may be used as precedent for future cases with identifying details removed, and 5) Parties may agree to share specific outcomes with the wider community when relevant to community functioning."
        }
      },
      process: {
        process_start: {
          processStartText: "The referee process begins when a community member submits a dispute resolution request form. This form includes a description of the issue, parties involved, desired outcome, and relevant documentation. Within 2 business days, the Dispute Coordinator reviews the form and determines if the referee process is appropriate. If so, the referee selection process begins immediately, with a goal of assigning a referee within 5 days of the initial submission."
        },
        facilitation: {
          facilitationText: "The dispute process is led by a single referee who: 1) Reviews all submitted materials before the first meeting, 2) Conducts individual intake interviews with each party, 3) Structures a joint session with clear speaking times and guidelines, 4) Asks clarifying questions to develop a complete understanding, 5) May request additional information or witnesses as needed, 6) Maintains control of the process while ensuring all voices are heard, and 7) Provides guidance on realistic options based on community standards."
        },
        ground_rules: {
          groundRulesText: "Communication in referee sessions follows structured guidelines: 1) The referee establishes clear speaking protocols at the start, 2) Each party has equal opportunity to present their perspective without interruption, 3) Questions are directed through the referee to maintain order, 4) Time limits ensure balanced participation, 5) The referee may caucus with parties separately when needed, 6) Communication focuses on facts and interests rather than accusations, and 7) The referee summarizes key points to ensure shared understanding. Parties commit to providing accurate information, responding to referee requests within specified timeframes, participating in scheduled meetings prepared and on time, and implementing required actions within established deadlines."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "The referee conducts a thorough situation assessment: 1) Identifying agreed-upon facts versus disputed facts, 2) Clarifying which community standards or agreements apply to the situation, 3) Determining the chronology of relevant events, 4) Assessing the impact on involved parties and the community, 5) Evaluating the credibility of conflicting accounts when necessary, and 6) Distinguishing between primary issues that require resolution and secondary factors. The referee also evaluates the stage and dynamics of the conflict including whether this is a new issue or part of an ongoing pattern and previous attempts at resolution."
        },
        jurisdiction: {
          jurisdictionText: "The referee process has jurisdiction over: 1) Interpretation and application of community agreements and policies, 2) Allocation of shared resources and spaces, 3) Interpersonal conflicts affecting community functioning, 4) Minor property disputes between community members, and 5) Compliance with previous community decisions. The process does not have jurisdiction over legal matters outside community governance, criminal activities, or disputes explicitly excluded in the community charter. Complex cases may be referred to specialized authorities when appropriate."
        },
        non_participation: {
          nonParticipationText: "Participation in the referee process is a condition of community membership as outlined in our community agreement. Members are expected to engage in good faith when named in a dispute. However, the process may proceed even if a party declines to participate actively. In such cases, the referee will consider available information and note the limited participation in their determination. When a case is accepted, the Dispute Coordinator contacts all identified parties via email and phone within 48 hours with information about the process."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "The referee gathers information through a structured approach: 1) Initial submissions from all parties, 2) Clarification questions to fill information gaps, 3) Targeted witness statements on specific disputed facts, 4) Review of community standards and precedents, 5) Site visits or physical inspections when relevant, and 6) Expert consultation on technical matters if needed. The process is designed to be thorough but efficient, gathering essential information without unnecessary delay."
        },
        additional_voices: {
          additionalVoicesText: "Participation typically includes: 1) The primary parties directly involved in the dispute, 2) The referee who facilitates and ultimately decides the case, 3) One support person per party (non-speaking unless invited), 4) Witnesses with relevant information (for specific portions only), 5) The Dispute Coordinator who handles logistics and record-keeping, and 6) Occasional observers for training purposes (with party consent)."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "Discussion in referee sessions is highly structured: 1) The referee identifies specific topics for focused conversation, 2) Each party has equal opportunity to address each topic, 3) Direct questions between parties are moderated by the referee, 4) The referee summarizes points of agreement and disagreement, 5) When positions differ, the referee explores underlying interests and concerns, and 6) The discussion concludes with a summary of key findings and possible resolution paths. The referee's deliberation typically includes a structured review of all gathered information with analysis of which community standards apply."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Decisions are made through a referee determination process: 1) The referee first encourages participants to reach their own agreement, 2) If parties cannot agree, the referee considers all presented information, 3) The decision is based on community standards, precedent, and fairness, 4) The referee provides a written determination with clear reasoning, 5) Parties may ask clarifying questions about the decision, 6) The referee has authority to make binding decisions within community governance, 7) Decisions are delivered within one week of the final session."
        },
        resolution_failure: {
          resolutionFailureText: "When resolution through the referee process is not achieved effectively, several options are available: 1) Escalation to a three-referee panel for complex cases, 2) Referral to professional mediation or arbitration services, 3) Consultation with subject matter experts on technical disputes, 4) Engagement of community leadership for policy-level issues, or 5) As a last resort, referral to appropriate legal authorities for matters beyond community governance. The Dispute Coordinator helps parties navigate these alternatives when necessary."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "Appeals of referee determinations may be filed based on limited criteria: 1) Significant new information that wasn't available during the original process, 2) Clear misapplication of community standards, 3) Procedural errors that materially affected the outcome, 4) Bias or conflict of interest that wasn't previously disclosed, or 5) Implementation impossibility due to factors outside the party's control. Appeals must be filed within 10 days of the determination and must specifically identify which criterion applies and provide supporting evidence."
        },
        appeal_process: {
          appealProcessText: "The appeal process follows these steps: 1) The appealing party submits a written appeal form with supporting documentation, 2) The Appeals Committee (consisting of three experienced referees not involved in the original case) reviews the appeal to determine if it meets criteria, 3) If accepted, a senior referee not involved in the original case is assigned, 4) The senior referee reviews all materials from the original case plus the appeal documentation, 5) A limited appeal hearing may be held to address specific issues, and 6) The senior referee issues a final determination that confirms, modifies, or replaces the original decision."
        }
      }
    }
  }
};

// Export the template
export default refereeProtocolTemplate;