// Restorative Justice Template

const restorativeJusticeTemplate = {
  id: "restorative-justice",
  title: "Restorative Justice",
  description: "A collaborative process that focuses on healing relationships and repairing harm rather than punitive measures",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Our community principles and restorative process guidelines are publicly available in multiple formats: a printed handbook in common spaces, an accessible online document, and visual displays in community gathering areas. New members receive an orientation to these principles when they join the community."
        },
        shared_values: {
          sharedValuesText: "Our restorative justice process is grounded in values of healing, accountability, and community wholeness. We believe that harm creates wounds in relationships that need healing rather than punishment. We value honest communication, deep listening, personal responsibility, and the wisdom that emerges from bringing affected people together in structured dialogue."
        },
        information_access: {
          informationAccessText: "Information about specific restorative processes is shared only with those directly involved. Statistical information about types of harm addressed (without identifying details) is shared annually to help the community learn and grow. The circle keeper maintains confidential records that are accessible only to them and the participants in each case."
        }
      },
      process: {
        process_start: {
          processStartText: "The restorative justice process begins when anyone in the community submits a request form indicating harm that needs to be addressed. This form asks for a brief description of what happened, who was involved, and what the person hopes might come from the process. A restorative justice coordinator acknowledges receipt within 24 hours and begins initial conversations with the person who submitted the request. Other participants are brought into the process through thoughtful invitation rather than formal notification."
        },
        facilitation: {
          facilitationText: "The dispute process uses a restorative circle approach: 1) A trained circle keeper facilitates but does not control the process, 2) All participants sit in a circle with no tables or barriers between them, 3) A talking piece is passed around the circle to ensure each person can speak without interruption, 4) Multiple rounds allow for deepening the conversation and moving toward resolution, 5) The circle process follows indigenous wisdom traditions adapted for contemporary contexts, 6) The circle keeper prepares participants individually before the full circle gathering."
        },
        ground_rules: {
          groundRulesText: "Communication in restorative circles follows these guidelines: 1) Speak from the heart about your own experience, 2) Listen from the heart without planning your response, 3) Speak with respect and without blame, 4) Share what's true for you in the moment, 5) Be mindful of time so everyone can share, 6) Honor the talking piece - only the person holding it may speak, 7) Respect the confidentiality of what is shared. Participants commit to: speaking honestly from their own experience, listening deeply to others without interruption, maintaining confidentiality, working toward understanding, and following through on agreements they make."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "The situation is assessed through a harm and needs framework: 1) Each participant describes what happened from their perspective, 2) Participants identify how they have been affected or harmed, 3) Underlying needs that weren't met are identified, 4) The impact on relationships and the wider community is explored, 5) The assessment focuses on understanding rather than blame. The circle keeper assesses the readiness of all parties for a restorative process, considering whether those who caused harm acknowledge their responsibility, the emotional state and safety needs of those who experienced harm, and the willingness of all parties to work toward repair."
        },
        jurisdiction: {
          jurisdictionText: "Our restorative justice process is appropriate for most interpersonal harms and conflicts within our community. For situations involving ongoing safety risks, legal violations that require reporting, or when participants are unwilling to acknowledge basic responsibility for harm, the process may be adapted or alternative resources recommended."
        },
        non_participation: {
          nonParticipationText: "Participation in restorative justice processes is entirely voluntary. We believe that genuine healing and transformation can only come from willing engagement. If someone chooses not to participate, we respect that decision and explore other paths forward with the person who initiated the request. The process may continue in modified form with those willing to participate, or may need to be redirected to other community resources."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "Information emerges organically through circle sharing. The process begins with establishing relationships and context before directly addressing the harm. Multiple rounds of the talking piece allow deeper layers of the situation to surface. As understanding develops, the circle considers what needs to happen to make things right. The circle keeper guides the process with thoughtful questions while allowing space for all voices."
        },
        additional_voices: {
          additionalVoicesText: "A restorative circle typically includes: 1) The person who experienced harm, 2) The person who caused harm, 3) Community members or loved ones who support each primary participant, 4) Community members affected by the situation, and 5) The circle keeper. Everyone participates as an equal in the circle, though the needs of those most affected guide the process."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "The circle discusses potential solutions through a structured process: 1) Each idea is considered in terms of how it addresses identified harms and needs, 2) Those most affected by the situation speak to what would help them move forward, 3) The group refines ideas based on what's practical and meaningful, 4) The keeper helps the group move toward consensus on actions for repair and healing. Deliberation happens within the circle format, and concludes when the group reaches shared agreements about how to move forward."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Decisions in restorative processes are made by consensus of all participants. The circle keeper helps test potential agreements to ensure everyone can support them. If perfect agreement isn't possible, the keeper helps craft a solution that addresses core needs while respecting individual boundaries about what people are willing to do. Restorative outcomes typically include: acknowledgment of the harm that occurred, specific actions to repair damage or address impacts, commitments to changed behavior in the future, healing rituals or symbolic acts, plans for rebuilding trust and relationships over time, and community support mechanisms to help implement agreements."
        },
        resolution_failure: {
          resolutionFailureText: "If the restorative process does not result in resolution, several options may be considered: 1) Taking a break and reconvening the circle at a later date when parties have had time to reflect, 2) Modifying the process to address barriers to resolution, 3) Bringing in additional circle keepers or community resources, 4) Referring to other conflict resolution processes like mediation, 5) In cases involving safety concerns or serious harm, connecting with appropriate professional or legal resources while maintaining support for all involved."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "Restorative processes can be reopened if: 1) Agreements aren't being fulfilled despite good faith efforts, 2) New information emerges that significantly changes understanding of the situation, 3) Additional harms occur related to the original situation, or 4) The process was completed but healing remains incomplete."
        },
        appeal_process: {
          appealProcessText: "To revisit a completed process, any participant can contact the circle keeper to request a follow-up circle. The keeper reaches out to all original participants to check willingness to reconvene. If everyone agrees, a new circle is scheduled focusing specifically on the issues that need further attention. The reconvened circle follows the same structured format as the original process but with focused attention on the specific concerns that led to reopening the case."
        }
      }
    }
  }
};

// Export the template
export default restorativeJusticeTemplate;