// Shalish Mediation Template

const shalishMediationTemplate = {
  id: "shalish-mediation",
  title: "Shalish Mediation",
  description: "A process based on the traditional shalish process for village-level mediation in Bangladesh, with modernizing improvements",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "The rules and procedures for the Shalish mediation process are documented in a community handbook that explains the cultural tradition and modern adaptations made by the Madaripur Legal Aid Association. This handbook is translated into local languages and made available through community centers, government offices, and through trained mediators."
        },
        shared_values: {
          sharedValuesText: "Shalish mediation centers on values of community harmony, restorative justice, and cultural respect. Mediators emphasize the importance of restoring relationships, fairness to all parties, and finding solutions that strengthen the community. Decisions are guided by local cultural norms and expectations alongside consideration of basic principles of justice and human dignity."
        },
        information_access: {
          informationAccessText: "Information about specific cases is kept confidential among the participating parties and mediators. Statistical information about types of cases addressed (without identifying details) is collected for program evaluation and improvement. Participants receive copies of any agreements they reach during the process."
        }
      },
      process: {
        process_start: {
          processStartText: "One or more disputant parties ask a third-party intervenor to assist in the dispute resolution process. If only one of the parties initiates the process, the other party/parties may or may not choose to participate. In the case of the latter, the mediator may require conflicting parties to submit to the mediation process. The mediator may need to educate one or more parties about the benefits of mediation for conflict resolution. Upon the agreement of all parties to participate, the mediator schedules a meeting time agreeable to all."
        },
        facilitation: {
          facilitationText: "Upon the decision to enter the mediation process from the disputant parties, the mediator decides whether to mediate alone or co-mediate. In the case of co-mediation, the mediators determine each others' responsibilities for the different aspects of the mediation process, safety valves in case of problems between mediators, time schedules, a mediation site, the management of case records, and similar housekeeping aspects. Each party is allowed to make an initial statement. The mediators take notes throughout the entire mediation process. Mediators may choose to meet privately with one or all of the disputant parties. In the end, the mediators help the disputants write an agreement."
        },
        ground_rules: {
          groundRulesText: "Communication in the mediation follows established ground rules: 1) Speak only for yourself and in the first person, 2) Use language that does not blame or find fault with others, 3) Do not interrupt while another is speaking, 4) Use non-inflammatory words, 5) If stating a complaint, raise it as your own concern and follow it with a constructive suggestion as to how it might be resolved, 6) Attack the problems and concerns at hand; do not attack the other person, 7) Make statements about your interests and needs instead of stating your position, 8) Be respectful to others, 9) Listen to understand what each person is saying without being judgmental about the person or the message."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "In issues of credibility, the mediators may share their understanding of the situation with the disputants. The mediators may also seek background information to receive clarity on what actually happened, in which case, common points are sought after to develop a consensual standard. If the parties fail to develop a standard, the mediator continues the mediation process with the hopes of a standard emerging later during the process."
        },
        jurisdiction: {
          jurisdictionText: "The aim of the mediation process is not to render a judgment, and mediators do not advocate for any one of the disputants. However, they may alternate representations between the parties. Mediators also do not act as social workers, therapists, or counselors. And, while mediators may encourage compliance with the law, they do not have the capacity to enforce the law, or even enforce agreements that disputants enter into between themselves."
        },
        non_participation: {
          nonParticipationText: "While participation is technically voluntary, there is often significant social expectation to engage in the process when invited. The community-based nature of the process means that refusing to participate can have social consequences. Mediators work to encourage participation by emphasizing benefits and addressing concerns."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "Information gathering happens through direct testimony from the disputing parties and relevant witnesses. The mediator guides this process, ensuring that all perspectives are heard. They hear all information, including hearsay, and encourage disputants to communicate directly with one another to establish the nature of the conflict."
        },
        additional_voices: {
          additionalVoicesText: "The mediation involves the disputing parties, the mediators, and sometimes community or family representatives who have a stake in the dispute. The mediator may invite specific individuals who can contribute to understanding the situation or implementing solutions. In some cases, the process may involve the whole community, especially when the dispute affects community resources or relationships."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "Discussion follows these principles: 1) If the disputants agree on what is credible, a mediator should not interject their own view of the conflict, even if it appears to be more sensible, 2) If the disputants disagree on what is credible, each party should be made responsible for spelling out what the differences are, 3) When there continues to be disagreement over what is credible, mediators should check their own perceptions of the situation with what the disputants say actually happened (i.e., they should 'reality test' their perceptions, but they should do so without judging the correctness or incorrectness of the disputants' perceptions)."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Resolution emerges through a process of negotiation and consensus-building facilitated by the mediator. The mediator does not impose solutions but helps parties identify mutually acceptable options. Once the disputants begin considering options for resolving their conflict, they enter into 'bargaining and negotiations' that involve a give-and-take on important issues."
        },
        resolution_failure: {
          resolutionFailureText: "When a resolution cannot be reached, the mediator may suggest: 1) Taking a break and reconvening later, 2) Bringing in additional community members to provide perspective, 3) Trying a different approach to the mediation process, 4) Referring the case to a more formal dispute resolution process, or 5) Engaging a different mediator or co-mediator who may have more credibility with the parties or expertise in the particular type of dispute."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "If parties are dissatisfied with the mediation outcome or if agreements are not being honored, they may request a follow-up mediation. This is appropriate when: 1) New information has emerged, 2) Circumstances have changed significantly, 3) Agreements have proven unworkable in practice, or 4) One party has failed to fulfill their commitments."
        },
        appeal_process: {
          appealProcessText: "To revisit a mediation, parties contact the original mediator or the coordinating organization. The mediator assesses the situation and may organize a follow-up session with all original participants. In some cases, a different mediator might be assigned if there are concerns about the original process."
        }
      }
    }
  }
};

// Export the template
export default shalishMediationTemplate;