// Transformative Justice Template

const transformativeJusticeTemplate = {
  id: "transformative-justice",
  title: "Transformative Justice",
  description: "A process that addresses immediate harm while working to transform the conditions that allowed harm to occur",
  data: {
    stages: {
      basics: {
        community_rules: {
          communityRulesText: "Our community agreements, values, and transformative justice framework are documented in accessible formats including a community handbook (print and digital), visual materials, audio resources, and multilingual versions. These resources clearly distinguish between aspirational values and concrete practices. All members participate in regular workshops to review and update these materials."
        },
        shared_values: {
          sharedValuesText: "Our transformative justice work is rooted in these core values: 1) Liberation - working toward freedom from all forms of oppression, 2) Accountability without punishment, 3) Collective responsibility for community well-being, 4) Radical honesty about impacts and conditions, 5) Compassion for all involved, including those who have caused harm, 6) Faith in people's capacity to transform, 7) Commitment to sustainable, long-term change."
        },
        information_access: {
          informationAccessText: "Information is shared based on a consent-based model. Those directly involved determine what information is shared beyond the immediate process. The transformative justice collective maintains secure records that include agreements made and lessons learned, but not sensitive personal details. Pattern-level information about types of harm addressed informs community education while protecting confidentiality."
        }
      },
      process: {
        process_start: {
          processStartText: "The transformative justice process begins when a community member reaches out to the transformative justice collective with a concern about harm. This initial contact can be through a secure online form, a phone line, or direct conversation with a collective member. Within 48 hours, two collective members are assigned to do an initial assessment and begin conversations with the person who raised the concern. People are brought into the process through intentional outreach by the facilitators, who explain the transformative approach and how it differs from punitive models."
        },
        facilitation: {
          facilitationText: "The dispute process uses a community accountability approach: 1) A facilitation team of 2-3 trained community members guides the process, 2) Both the person harmed and the person who caused harm have support teams, 3) The wider community is represented by stakeholders affected by the issues, 4) The process begins with individual preparation sessions before group meetings, 5) Facilitation focuses on transforming harmful patterns, not just individual incidents, 6) Multiple sessions allow for deep exploration of systemic factors, 7) The process builds community capacity to address similar issues in the future."
        },
        ground_rules: {
          groundRulesText: "Communication follows these agreements: 1) Speak from personal experience using 'I' statements, 2) Acknowledge the difference between intent and impact, 3) Use language that recognizes both individual and systemic dimensions, 4) Name patterns and power dynamics when relevant, 5) Practice active listening, 6) Honor silence and processing time, 7) Express needs directly rather than through criticism. Participants commit to engaging honestly in examining harm and its impacts, considering both individual and collective dimensions of accountability, respecting confidentiality boundaries, working to understand systemic factors beyond individual actions, contributing to implementation of agreements, and participating in follow-up."
        }
      },
      assessment: {
        dispute_assessment: {
          disputeAssessmentText: "The situation is assessed through a systemic analysis framework: 1) Individual experiences and harms are documented, 2) Patterns of behavior and power dynamics are identified, 3) Structural factors that contributed to the harm are analyzed, 4) Community norms and cultural assumptions are examined, 5) The assessment connects individual incidents to broader social contexts. The facilitation team assesses the history and timeline of the harm, whether this is an isolated incident or part of a pattern, the presence of immediate safety concerns, and the current capacity of all involved to engage in the process."
        },
        jurisdiction: {
          jurisdictionText: "Transformative justice processes are most appropriate for situations where: 1) The harm is connected to broader social patterns, 2) Community-based intervention is possible and desired, 3) There is willingness to address both immediate harm and root causes, and 4) Public systems (legal, etc.) would likely cause additional harm. The process may be adapted based on safety needs and legal requirements."
        },
        non_participation: {
          nonParticipationText: "Participation is voluntary but strongly encouraged as part of our community commitments. We recognize that meaningful accountability cannot be forced. However, if someone chooses not to participate directly, the process may continue with those who are willing, focusing on community support for those harmed and addressing systemic factors that contributed to the harm."
        }
      },
      deliberation: {
        deliberation_process: {
          deliberationProcessText: "Information is gathered through a trauma-informed approach that centers those most impacted. Multiple sessions allow time for reflection and integration. The facilitation team helps contextualize individual experiences within systemic patterns, gathering information about both the specific harm and the conditions that enabled it. The deliberation process includes multiple formats including structured dialogue sessions, caucus meetings with specific stakeholder groups, one-on-one conversations for sensitive topics, and community forums for systemic issues."
        },
        additional_voices: {
          additionalVoicesText: "The process includes a constellation of participants depending on the situation: 1) Core participants directly involved in the harm, 2) Support people chosen by core participants, 3) Facilitators from the transformative justice collective, 4) Community stakeholders who represent affected groups or have relevant expertise, 5) Witnesses who help document and hold the process. Each participant has a specific role with clear responsibilities."
        },
        deliberation_conclusion: {
          deliberationConclusionText: "Facilitated discussions focus on building shared understanding of how change can happen at multiple levels. Participants examine proposed solutions in terms of how they address immediate needs, build accountability, heal relationships, transform conditions, and prevent future harm. Special attention is paid to sustainability and community capacity. Solution-building happens through structured brainstorming processes that include small group work to generate ideas addressing different levels of change, research into approaches used by other communities, and consultation with relevant experts or elders."
        }
      },
      resolution: {
        resolution_process: {
          resolutionProcessText: "Decisions are made through a consensus process that prioritizes the needs of those most impacted while engaging everyone in finding solutions. The facilitation team helps test proposals against transformative justice principles. When full consensus isn't possible, the group identifies which elements have universal support and which need further development. Outcomes address multiple dimensions: survivor-centered responses to address immediate harm, accountability processes for those who caused harm, community support mechanisms, education initiatives to build awareness, policy or structural changes to transform conditions, and community capacity-building to sustain changes over time."
        },
        resolution_failure: {
          resolutionFailureText: "If the transformative justice process does not achieve its goals, several approaches may be considered: 1) Extending the timeline to allow for deeper work, 2) Bringing in additional resources or facilitators with specialized expertise, 3) Narrowing the focus to address the most critical aspects first, 4) Dividing the work into parallel processes addressing different levels (individual healing, accountability, systemic change), or 5) When necessary, connecting participants with alternative resources while maintaining community support. The goal remains transformation rather than punishment, even when the initial process requires adaptation."
        }
      },
      appeal: {
        appeal_criteria: {
          appealCriteriaText: "The process can be revisited if: 1) Agreements aren't being implemented as planned, 2) Implementation reveals unforeseen challenges, 3) New information emerges about the situation, 4) The harm continues or recurs, 5) Systemic changes aren't effectively addressing root causes, or 6) Additional affected parties come forward."
        },
        appeal_process: {
          appealProcessText: "Any participant can request reassessment by contacting the transformative justice collective. Two members review the request and consult with key stakeholders to determine next steps. This may lead to reconvening the original group, forming a new group, or taking targeted action on specific unaddressed issues. Reassessment follows a structured format with review of original agreements and implementation status, identification of gaps or new issues, and analysis of why certain aspects haven't been effective."
        }
      }
    }
  }
};

// Export the template
export default transformativeJusticeTemplate;